<?php

namespace Drupal\entity_reference_media\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Field\Plugin\Field\FieldType\EntityReferenceItem;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\TypedData\DataDefinition;

/**
 * @FieldType(
 *     id = "entity_reference_media",
 *     label = @Translation("Entity reference media w/caption"),
 *     description = @Translation("Entity reference media with caption text"),
 *     category = @Translation("Reference"),
 *     default_widget = "entity_reference_media_library",
 *     default_formatter = "entity_reference_media_entity",
 *     list_class = "\Drupal\Core\Field\EntityReferenceFieldItemList",
 * )
 */
class EntityReferenceMedia extends EntityReferenceItem {

  /**
   * {@inheritDoc}
   */
  public static function defaultStorageSettings() {
    return [
        'target_type' => 'media',
      ] + parent::defaultStorageSettings();
  }

  /**
   * {@inheritDoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties = parent::propertyDefinitions($field_definition);

    $properties['default_caption'] = DataDefinition::create('boolean')
      ->setLabel(new TranslatableMarkup('Show default caption'))
      ->setRequired(FALSE);

    $properties['custom_caption'] = DataDefinition::create('string')
      ->setLabel(new TranslatableMarkup('Custom caption text'))
      ->setRequired(FALSE);

    return $properties;
  }

  /**
   * {@inheritDoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $schema = parent::schema($field_definition);

    $schema['columns']['default_caption'] = [
      'type' => 'int',
      'size' => 'tiny',
    ];

    $schema['columns']['custom_caption'] = [
      'type' => 'text',
      'size' => 'big',
    ];

    return $schema;
  }

  /**
   * {@inheritDoc}
   */
  public static function getPreconfiguredOptions() {
    return [];
  }

}
