<?php

namespace Drupal\entity_reference_media\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media_library\Plugin\Field\FieldWidget\MediaLibraryWidget;

/**
 * @FieldWidget(
 *   id = "entity_reference_media_library",
 *   label = @Translation("Media library"),
 *   description = @Translation("Allows you to select items from the media
 *   library."), field_types = {
 *     "entity_reference_media"
 *   },
 *   multiple_values = TRUE,
 * )
 */
class EntityReferenceMediaWidget extends MediaLibraryWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $referencedEntities = $items->referencedEntities();
    $fieldName = $this->fieldDefinition->getName();

    foreach ($referencedEntities as $delta => $mediaItem) {
      $referenceField = $items->get($delta);

      $states_parents = array_merge($element["#field_parents"], [$fieldName], ['selection'], [$delta], ['default_caption']);
      $states_prefix = array_shift($states_parents);
      $states_prefix .= '[' . implode('][', $states_parents) . ']';

      if ($referenceField->getFieldDefinition()
          ->getType() == 'entity_reference_media') {
        $element['selection'][$delta]['default_caption'] = [
          "#type" => "checkbox",
          "#title" => $this->t("Show default caption text"),
          "#default_value" => $referenceField->default_caption != NULL ? $referenceField->default_caption : TRUE,
        ];
        $element['selection'][$delta]['custom_caption'] = [
          '#type' => 'textarea',
          '#default_value' => $referenceField->custom_caption,
          '#states' => [
            'visible' => [
              ':input[name="' . $states_prefix . '"]' => ['unchecked' => TRUE],
            ],
          ],
        ];
      }
    }

    return $element;
  }

}
